==> filmeverwaltung-0.0.2.tar.bz2: filmeverwaltung/einlesen.php <==
<?php
// filmeverwaltung - einlesen.php       Copyright (C) 2009 Oliver Burger
// oliver [at] mandrivauser [dot] de    http://www.mandrivauser.de
//
// This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//

	// beginnendes HTML-Gedöhns
	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">
	<HTML>
	<Head>
	<Title>
		CD-Register
	</Title>
	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">
	<link rel=stylesheet type=\"text/css\" href=\"./style_eingabe.css\">
	</Head>
	<Body bgcolor=\"#f0f0ff\" text=\"#000044\">";
	echo "<h1>Filmesammlungs-Verwaltung</h1>
		<p>Hier k&ouml;nnen Sie neue Eintr&auml;ge in Ihre Sammlung
		aufnehmen</p><br />";
	echo "&nbsp;|&nbsp;
		<a href=\"./index.php\">&Uuml;bersicht</a> &nbsp;|&nbsp;
		<font color=\"#cc00cc\" size=\"+1\"><b>Einlesen neuer Filme</b>
		</font> &nbsp;|&nbsp;
		<a href=\"./korrektur.php\">Korrektur von Eintr&auml;gen</a>
		&nbsp;|&nbsp<br /><br />";

	// Deklaration der benoetigten Arrays
	$raw_register = array();
	$register = array();

	// Einlesen der Datei
	$data_file = fopen("data/cd-register","r");
	while(!feof($data_file))
	{
		$zeile = fgets($data_file,1024);
		$raw_register[] = $zeile;
	}
	fclose($data_file);

	// Erstellen des Haupt-Arrays
	for($i = 0; $i < count($raw_register)-1; $i++)
	{
		$register[$i] = explode("|",$raw_register[$i]);
	}

	// Eingabe der Daten
	echo "<form action=\"./einlesen.php\" method=\"post\">
	<table><tr><th>Film</th>
	<th>Genre</th>
	<th>Schauspieler</th>
	<th>CD-Case</th>
	<th>Medien-Nummer</th></tr>
	<tr><td><input type=\"Text\" name=\"filmname\"></td>
	<td><input type=\"Text\" name=\"genre\" accept-charset=\"ISO-8859-1\"></td>
	<td><input type=\"Text\" name=\"schauspieler\"></td>
	<td><input type=\"Text\" name=\"cd_case\"></td>
	<td><input type=\"Text\" name=\"medien_nummer\"></td>
	</tr></table><br />
	<input type=\"Submit\" value=\"Absenden\">
	</form><br />";

	// Auslesen der Einnahmen
	$filmname = $_POST["filmname"];
	$genre = $_POST["genre"];
	$schauspieler = $_POST["schauspieler"];
	$cd_case = $_POST["cd_case"];
	$medien_nummer = $_POST["medien_nummer"];

	if($filmname != "")
	{
		$eingabe = array();
		$eingabe[0]=$filmname;
		$eingabe[1]=$genre;
		$eingabe[2]=$schauspieler;
		$eingabe[3]=$cd_case;
		$eingabe[4]=$medien_nummer."\n";
		// Konvertieren der Sonderzeichen
		for($i=0; $i<5; $i++)
		{
			$eingabe[$i]=htmlentities($eingabe[$i]);
		}
		$filmnummer=count($register);
		$register[$filmnummer]=$eingabe;
	}
	else
	{
		if($genre != "" AND $schauspieler != "" AND $cd_case != ""
			AND $medien_nummer != "\n")
		{
			echo "<br /><br /><p>Der Filmname wurde nicht
				angegeben</p><br /><br />";
		}
	}
		
	// Ausgabe der Tabelle
	echo "<table border=1>
		<tr><th>Nr.<th>Titel</th><th>Genre</th><th>Schauspieler</th>
		<th>CD-Case</th><th>Medien-Nummer</th></tr>";
	for($i=0;$i<count($register);$i++)
	{
		echo "<tr><td>".$i."</td><td>".$register[$i][0]."</td>
		<td>".$register[$i][1]."</td><td>".$register[$i][2]."</td>
		<td>".$register[$i][3]."</td><td>".$register[$i][4]."</td>
		</tr>";
	}
	echo "</table>";

	// Abspeichern der Daten
	if($filmname != "")
	{
		for($i=0; $i<count($register); $i++)
		{
			$raw_register[$i] = implode("|",$register[$i]);
		}
	
		// Speichern der Daten in die Datei
		$data_file = fopen("data/cd-register","a+");
		$i=count($raw_register)-1;
		$zeile = $raw_register[$i];
		fputs($data_file,$zeile);
		#fputs($data_file,$raw_register);
		fclose($data_file);
		echo "<br /><p>Die &Auml;nderungen wurden gespeichert.</p>
			<br />";
	}	

	// abschließendes HTML-Gedöhns...
echo "<br /><a href=\"#top\">Nach oben</a>";

	echo "</Body>
	</HTML>";

?>

==> filmeverwaltung-0.0.2.1.tar.bz2: filmeverwaltung/einlesen.php <==
<?php
// This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//

	// beginnendes HTML-Gedöhns
	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">
	<HTML>
	<Head>
	<Title>
		CD-Register
	</Title>
	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">
	<link rel=stylesheet type=\"text/css\" href=\"./style_eingabe.css\">
	</Head>
	<Body bgcolor=\"#f0f0ff\" text=\"#000044\">";
	echo "<h1>Filmesammlungs-Verwaltung</h1>
		<p>Hier k&ouml;nnen Sie neue Eintr&auml;ge in Ihre Sammlung
		aufnehmen</p><br />";
	echo "&nbsp;|&nbsp;
		<a href=\"./index.php\">&Uuml;bersicht</a> &nbsp;|&nbsp;
		<font color=\"#cc00cc\" size=\"+1\"><b>Einlesen neuer Filme</b>
		</font> &nbsp;|&nbsp;
		<a href=\"./korrektur.php\">Korrektur von Eintr&auml;gen</a>
		&nbsp;|&nbsp<br /><br />";

	// Deklaration der benoetigten Arrays
	$raw_register = array();
	$register = array();

	// Einlesen der Datei
	$data_file = fopen("data/cd-register","r");
	while(!feof($data_file))
	{
		$zeile = fgets($data_file,1024);
		$raw_register[] = $zeile;
	}
	fclose($data_file);

	// Erstellen des Haupt-Arrays
	for($i = 0; $i < count($raw_register)-1; $i++)
	{
		$register[$i] = explode("|",$raw_register[$i]);
	}

	// Eingabe der Daten
	echo "<form action=\"./einlesen.php\" method=\"post\">
	<table width=><tr>
	<th width=>Film</th>
	<th width=>Genre</th>
	<th width=>Schauspieler</th>
	<th width=>CD-Case</th>
	<th width=>Medien-Nummer</th></tr>
	<tr><td><input type=\"Text\" name=\"filmname\"></td>
	<td><input type=\"Text\" name=\"genre\" accept-charset=\"ISO-8859-1\"></td>
	<td><input type=\"Text\" name=\"schauspieler\"></td>
	<td><input type=\"Text\" name=\"cd_case\"></td>
	<td><input type=\"Text\" name=\"medien_nummer\"></td>
	</tr></table><br />
	<input type=\"Submit\" value=\"Absenden\">
	</form><br />";

	// Auslesen der Einnahmen
	$filmname = $_POST["filmname"];
	$genre = $_POST["genre"];
	$schauspieler = $_POST["schauspieler"];
	$cd_case = $_POST["cd_case"];
	$medien_nummer = $_POST["medien_nummer"];

	if($filmname != "")
	{
		$eingabe = array();
		$eingabe[0]=$filmname;
		$eingabe[1]=$genre;
		$eingabe[2]=$schauspieler;
		$eingabe[3]=$cd_case;
		$eingabe[4]=$medien_nummer."\n";
		// Konvertieren der Sonderzeichen
		for($i=0; $i<5; $i++)
		{
			$eingabe[$i]=htmlentities($eingabe[$i]);
		}
		$filmnummer=count($register);
		$register[$filmnummer]=$eingabe;
	}
	else
	{
		if($genre != "" AND $schauspieler != "" AND $cd_case != ""
			AND $medien_nummer != "\n")
		{
			echo "<br /><br /><p>Der Filmname wurde nicht
				angegeben</p><br /><br />";
		}
	}
		
	// Ausgabe der Tabelle
	echo "<table border=1 width=\"98%\"><tr>
		<th width=\"3%\">Nr.</th>
		<th width=\"29%\">Titel</th>
		<th width=\"15%\">Genre</th>
		<th width=\"29%\">Schauspieler</th>
		<th width=\"10%\">CD-Case</th>
		<th width=\"14%\">Medien-Nummer</th></tr>";
	for($i=0;$i<count($register);$i++)
	{
		echo "<tr><td>".$i."</td><td>".$register[$i][0]."</td>
		<td>".$register[$i][1]."</td><td>".$register[$i][2]."</td>
		<td>".$register[$i][3]."</td><td>".$register[$i][4]."</td>
		</tr>";
	}
	echo "</table>";

	// Abspeichern der Daten
	if($filmname != "")
	{
		for($i=0; $i<count($register); $i++)
		{
			$raw_register[$i] = implode("|",$register[$i]);
		}
	
		// Speichern der Daten in die Datei
		$data_file = fopen("data/cd-register","a+");
		$i=count($raw_register)-1;
		$zeile = $raw_register[$i];
		fputs($data_file,$zeile);
		#fputs($data_file,$raw_register);
		fclose($data_file);
		echo "<br /><p>Die &Auml;nderungen wurden gespeichert.</p>
			<br />";
	}	

	// abschließendes HTML-Gedöhns...
echo "<br /><a href=\"#top\">Nach oben</a>";

	echo "</Body>
	</HTML>";

?>
